@@ -397,19 +397,19 @@ def matam_16s(args):
 if __name__ == '__main__':
 
     matam_16s_parser = argparse.ArgumentParser()
-    matam_16s_parser.add_argument('-p',              required=True,                                                     help='output prefix')
-    matam_16s_parser.add_argument('-r1',             required=False, default=None,                                      help='forward reads')
-    matam_16s_parser.add_argument('-r2',             required=False, default=None,                                      help='reverse reads')
-    matam_16s_parser.add_argument('-r16s',           required=False, default=None,                                      help='extracted 16S reads, specify if you already have 16S reads identified from metagenomic dataset')
-    matam_16s_parser.add_argument('-pct',            required=True,  type=str, default='1,5,10,25,50,75,100',           help='subsample percentage, must be integer, between 1-100, deafault: 1,5,10,25,50,75,100')
-    matam_16s_parser.add_argument('-d',              required=False, type=str,                                          help='MATAM ref db, same as "-d" in Matam')
-    matam_16s_parser.add_argument('-i',              required=False, type=float, default=0.999,                         help='cluster identity cutoff, do not provide value lower than 0.99, default: 0.999')
-    matam_16s_parser.add_argument('-t',              required=False, type=int, default=1,                               help='number of threads, default: 1')
-    matam_16s_parser.add_argument('-mem',            required=False, type=int, default=10240,                           help='Maximum memory to be allocated to Matam (in MB), default: 10240')
-    matam_16s_parser.add_argument('-force',          required=False, action="store_true",                               help='force overwrite existing results')
-    matam_16s_parser.add_argument('-quiet',          required=False, action="store_true",                               help='not report progress')
-    matam_16s_parser.add_argument('-matam',          required=False, type=str, default='matam_assembly.py',             help='path to matam_assembly.py, default: matam_assembly.py')
-    matam_16s_parser.add_argument('-seqtk',          required=False, type=str, default='seqtk',                         help='path to seqtk executable file, default: seqtk')
-    matam_16s_parser.add_argument('-usearch',        required=False, type=str, default='usearch',                       help='path to usearch executable file, default: usearch')
+    matam_16s_parser.add_argument('-p',              required=True,  metavar='',                                            help='output prefix')
+    matam_16s_parser.add_argument('-r1',             required=False, metavar='', default=None,                              help='forward reads')
+    matam_16s_parser.add_argument('-r2',             required=False, metavar='', default=None,                              help='reverse reads')
+    matam_16s_parser.add_argument('-r16s',           required=False, metavar='', default=None,                              help='extracted 16S reads, specify if you already have 16S reads identified from metagenomic dataset')
+    matam_16s_parser.add_argument('-pct',            required=True,  metavar='', type=str, default='1,5,10,25,50,75,100',   help='subsample percentage, must be integer, between 1-100, deafault: 1,5,10,25,50,75,100')
+    matam_16s_parser.add_argument('-d',              required=False, metavar='', type=str,                                  help='MATAM ref db, same as "-d" in Matam')
+    matam_16s_parser.add_argument('-i',              required=False, metavar='', type=float, default=0.999,                 help='cluster identity cutoff, do not provide value lower than 0.99, default: 0.999')
+    matam_16s_parser.add_argument('-t',              required=False, metavar='', type=int, default=1,                       help='number of threads, default: 1')
+    matam_16s_parser.add_argument('-mem',            required=False, metavar='', type=int, default=10240,                   help='Maximum memory to be allocated to Matam (in MB), default: 10240')
+    matam_16s_parser.add_argument('-force',          required=False, action="store_true",                                   help='force overwrite existing results')
+    matam_16s_parser.add_argument('-quiet',          required=False, action="store_true",                                   help='not report progress')
+    matam_16s_parser.add_argument('-matam',          required=False, metavar='', type=str, default='matam_assembly.py',     help='path to matam_assembly.py, default: matam_assembly.py')
+    matam_16s_parser.add_argument('-seqtk',          required=False, metavar='', type=str, default='seqtk',                 help='path to seqtk executable file, default: seqtk')
+    matam_16s_parser.add_argument('-usearch',        required=False, metavar='', type=str, default='usearch',               help='path to usearch executable file, default: usearch')
     args = vars(matam_16s_parser.parse_args())
     matam_16s(args)
